"""Common configuration constants
"""

PROJECTNAME = 'ATGoogleMaps'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'GMap' : 'ATGoogleMaps: Add GMap',
    'GMarker' : 'ATGoogleMaps: Add GMarker',
}
